@@ -15,6 +15,8 @@ from click import echo
 
 from ..decorators import (
     bunch_size_option,
+    end_date_option,
+    start_date_option,
     timeout_option,
     pass_client,
     pass_session
@@ -27,7 +29,7 @@ from ..exceptions import (
     VoucherNeedRefresh
 )
 from ..models import Library
-from ..utils import Downloader
+from ..utils import datetime_type, Downloader
 
 
 logger = logging.getLogger("audible_cli.cmds.cmd_download")
@@ -35,13 +37,6 @@ logger = logging.getLogger("audible_cli.cmds.cmd_download")
 CLIENT_HEADERS = {
     "User-Agent": "Audible/671 CFNetwork/1240.0.4 Darwin/20.6.0"
 }
-datetime_type = click.DateTime([
-    "%Y-%m-%d",
-    "%Y-%m-%dT%H:%M:%S",
-    "%Y-%m-%d %H:%M:%S",
-    "%Y-%m-%dT%H:%M:%S.%fZ",
-    "%Y-%m-%dT%H:%M:%SZ"
-])
 
 
 class DownloadCounter:
@@ -173,7 +168,7 @@ async def download_cover(
     url = item.get_cover_url(res)
     if url is None:
         logger.error(
-            f"No COVER found for {item.full_title} with given resolution"
+            f"No COVER with size {res} found for {item.full_title}"
         )
         return
 
@@ -446,7 +441,7 @@ def queue_job(
         output_dir,
         filename_mode,
         item,
-        cover_size,
+        cover_sizes,
         quality,
         overwrite_existing,
         aax_fallback
@@ -454,16 +449,17 @@ def queue_job(
     base_filename = item.create_base_filename(filename_mode)
 
     if get_cover:
-        queue.put_nowait(
-            download_cover(
-                client=client,
-                output_dir=output_dir,
-                base_filename=base_filename,
-                item=item,
-                res=cover_size,
-                overwrite_existing=overwrite_existing
+        for cover_size in cover_sizes:
+            queue.put_nowait(
+                download_cover(
+                    client=client,
+                    output_dir=output_dir,
+                    base_filename=base_filename,
+                    item=item,
+                    res=cover_size,
+                    overwrite_existing=overwrite_existing
+                )
             )
-        )
 
     if get_pdf:
         queue.put_nowait(
@@ -602,8 +598,9 @@ def display_counter():
     "--cover-size",
     type=click.Choice(["252", "315", "360", "408", "500", "558", "570", "882",
                        "900", "1215"]),
-    default="500",
-    help="the cover pixel size"
+    default=["500"],
+    multiple=True,
+    help="The cover pixel size. This option can be provided multiple times."
 )
 @click.option(
     "--chapter",
@@ -615,18 +612,8 @@ def display_counter():
     is_flag=True,
     help="saves the annotations (e.g. bookmarks, notes) as JSON file"
 )
-@click.option(
-    "--start-date",
-    type=datetime_type,
-    default="1970-1-1",
-    help="Only considers books added to library on or after this UTC date."
-)
-@click.option(
-    "--end-date",
-    type=datetime_type,
-    default=datetime.utcnow(),
-    help="Only considers books added to library on or before this UTC date."
-)
+@start_date_option
+@end_date_option
 @click.option(
     "--no-confirm", "-y",
     is_flag=True,
@@ -709,7 +696,7 @@ async def cli(session, api_client, **params):
     # additional options
     sim_jobs = params.get("jobs")
     quality = params.get("quality")
-    cover_size = params.get("cover_size")
+    cover_sizes = list(set(params.get("cover_size")))
     overwrite_existing = params.get("overwrite")
     ignore_errors = params.get("ignore_errors")
     no_confirm = params.get("no_confirm")
@@ -717,16 +704,20 @@ async def cli(session, api_client, **params):
     ignore_podcasts = params.get("ignore_podcasts")
     bunch_size = session.params.get("bunch_size")
 
-    start_date = params.get("start_date")
-    purchased_after = start_date.strftime('%Y-%m-%dT%H:%M:%S.%fZ')
-    end_date = params.get("end_date")
-    if start_date > end_date:
+    start_date = session.params.get("start_date")
+    end_date = session.params.get("end_date")
+    if all([start_date, end_date]) and start_date > end_date:
         logger.error("start date must be before or equal the end date")
         raise click.Abort()
 
-    logger.info(f"Selected start date: {purchased_after}")
-    logger.info(
-        f"Selected end   date: {end_date.strftime('%Y-%m-%dT%H:%M:%S.%fZ')}")
+    if start_date is not None:
+        logger.info(
+            f"Selected start date: {start_date.strftime('%Y-%m-%dT%H:%M:%S.%fZ')}"
+        )
+    if end_date is not None:
+        logger.info(
+            f"Selected end date: {end_date.strftime('%Y-%m-%dT%H:%M:%S.%fZ')}"
+        )
 
     filename_mode = params.get("filename_mode")
     if filename_mode == "config":
@@ -736,18 +727,19 @@ async def cli(session, api_client, **params):
     # fetch the user library
     library = await Library.from_api_full_sync(
         api_client,
-        image_sizes="1215, 408, 360, 882, 315, 570, 252, 558, 900, 500",
+        image_sizes=", ".join(cover_sizes),
         bunch_size=bunch_size,
         response_groups=(
             "product_desc, media, product_attrs, relationships, "
             "series, customer_rights, pdf_url"
         ),
-        purchased_after=purchased_after,
+        start_date=start_date,
+        end_date=end_date,
         status="Active",
     )
 
     if resolve_podcats:
-        await library.resolve_podcats()
+        await library.resolve_podcats(start_date=start_date, end_date=end_date)
 
     # collect jobs
     jobs = []
@@ -805,7 +797,9 @@ async def cli(session, api_client, **params):
         if not ignore_podcasts and item.is_parent_podcast():
             items.remove(item)
             if item._children is None:
-                await item.get_child_items()
+                await item.get_child_items(
+                    start_date=start_date, end_date=end_date
+                )
 
             for i in item._children:
                 if i.asin not in jobs:
@@ -817,27 +811,23 @@ async def cli(session, api_client, **params):
                 odir.mkdir(parents=True)
 
         for item in items:
-            purchase_date = datetime_type.convert(
-                item.purchase_date, None, None
+            queue_job(
+                queue=queue,
+                get_cover=get_cover,
+                get_pdf=get_pdf,
+                get_annotation=get_annotation,
+                get_chapters=get_chapters,
+                get_aax=get_aax,
+                get_aaxc=get_aaxc,
+                client=client,
+                output_dir=odir,
+                filename_mode=filename_mode,
+                item=item,
+                cover_sizes=cover_sizes,
+                quality=quality,
+                overwrite_existing=overwrite_existing,
+                aax_fallback=aax_fallback
             )
-            if start_date <= purchase_date <= end_date:
-                queue_job(
-                    queue=queue,
-                    get_cover=get_cover,
-                    get_pdf=get_pdf,
-                    get_annotation=get_annotation,
-                    get_chapters=get_chapters,
-                    get_aax=get_aax,
-                    get_aaxc=get_aaxc,
-                    client=client,
-                    output_dir=odir,
-                    filename_mode=filename_mode,
-                    item=item,
-                    cover_size=cover_size,
-                    quality=quality,
-                    overwrite_existing=overwrite_existing,
-                    aax_fallback=aax_fallback
-                )
 
     try:
         # schedule the consumer
@@ -853,4 +843,4 @@ async def cli(session, api_client, **params):
             consumer.cancel()
 
         await asyncio.gather(*consumers, return_exceptions=True)
-        display_counter()
\ No newline at end of file
+        display_counter()
